@@ -78,6 +78,34 @@ def test_writer_clone():
     assert "PageObject" in str(type(writer.pages[0]))
 
 
+def test_clone_metadata():
+    src = RESOURCE_ROOT / "pdflatex-outline.pdf"
+    reader = PdfReader(src)
+
+    writer = PdfWriter(clone_from=reader)
+    writer.add_metadata({"/foo": "bar"})
+    assert writer.metadata == {
+        **reader.metadata,
+        "/foo": "bar",
+    }
+
+    writer = PdfWriter()
+    writer.clone_document_from_reader(reader)
+    writer.add_metadata({"/foo": "bar"})
+    assert writer.metadata == {
+        **reader.metadata,
+        "/foo": "bar",
+    }
+    writer.metadata = None
+    writer.add_metadata({"/foo": "bar"})
+    assert writer.metadata == {"/foo": "bar"}
+
+    writer = PdfWriter()
+    writer.clone_reader_document_root(reader)
+    writer.add_metadata({"/foo": "bar"})
+    assert writer.metadata == {"/foo": "bar"}
+
+
 def test_writer_clone_bookmarks():
     # Arrange
     src = RESOURCE_ROOT / "Seige_of_Vicksburg_Sample_OCR-crazyones-merged.pdf"
@@ -623,9 +651,9 @@ def test_add_outline_item(pdf_file_path):
         reader = PdfReader(output_stream)
         assert reader.trailer["/Root"]["/Outlines"]["/Count"] == 3
         assert reader.outline[0]["/Count"] == -2
-        assert reader.outline[0]["/%is_open%"] == False  # noqa
+        assert reader.outline[0]["/%is_open%"] == False  # noqa: E712
         assert reader.outline[2]["/Count"] == 2
-        assert reader.outline[2]["/%is_open%"] == True  # noqa
+        assert reader.outline[2]["/%is_open%"] == True  # noqa: E712
         assert reader.outline[1][0]["/Count"] == 0
 
 
@@ -660,7 +688,7 @@ def test_add_named_destination(pdf_file_path):
     assert writer.get_object(root[1].idnum) == writer.get_object(root[1])
     with pytest.raises(ValueError) as exc:
         writer.get_object(reader.pages[0].indirect_reference)
-    assert exc.value.args[0] == "pdf must be self"
+    assert exc.value.args[0] == "PDF must be self"
 
     # write "output" to pypdf-output.pdf
     with open(pdf_file_path, "wb") as output_stream:
@@ -837,7 +865,7 @@ def test_append_pages_from_reader_append():
 @pytest.mark.filterwarnings("ignore::DeprecationWarning")
 def test_sweep_indirect_references_nullobject_exception(pdf_file_path):
     # TODO: Check this more closely... this looks weird
-    url = "https://corpora.tika.apache.org/base/docs/govdocs1/924/924666.pdf"
+    url = "https://github.com/user-attachments/files/18381699/tika-924666.pdf"
     name = "tika-924666.pdf"
     reader = PdfReader(BytesIO(get_data_from_url(url, name=name)))
     merger = PdfWriter()
@@ -851,11 +879,11 @@ def test_sweep_indirect_references_nullobject_exception(pdf_file_path):
     ("url", "name"),
     [
         (
-            "https://corpora.tika.apache.org/base/docs/govdocs1/924/924666.pdf",
+            "https://github.com/user-attachments/files/18381699/tika-924666.pdf",
             "test_sweep_indirect_references_nullobject_exception.pdf",
         ),
         (
-            "https://corpora.tika.apache.org/base/docs/govdocs1/922/922840.pdf",
+            "https://github.com/user-attachments/files/18381694/tika-922840.pdf",
             "test_write_outline_item_on_page_fitv.pdf",
         ),
         ("https://github.com/py-pdf/pypdf/files/10715624/test.pdf", "iss1627.pdf"),
@@ -1042,7 +1070,7 @@ def test_iss471():
 
 @pytest.mark.enable_socket
 def test_reset_translation():
-    url = "https://corpora.tika.apache.org/base/docs/govdocs1/924/924666.pdf"
+    url = "https://github.com/user-attachments/files/18381699/tika-924666.pdf"
     name = "tika-924666.pdf"
     reader = PdfReader(BytesIO(get_data_from_url(url, name=name)))
     writer = PdfWriter()
@@ -1080,7 +1108,7 @@ def test_threads_empty():
 
 @pytest.mark.enable_socket
 def test_append_without_annots_and_articles():
-    url = "https://corpora.tika.apache.org/base/docs/govdocs1/924/924666.pdf"
+    url = "https://github.com/user-attachments/files/18381699/tika-924666.pdf"
     name = "tika-924666.pdf"
     reader = PdfReader(BytesIO(get_data_from_url(url, name=name)))
     writer = PdfWriter()
@@ -1099,7 +1127,7 @@ def test_append_without_annots_and_articles():
 
 @pytest.mark.enable_socket
 def test_append_multiple():
-    url = "https://corpora.tika.apache.org/base/docs/govdocs1/924/924666.pdf"
+    url = "https://github.com/user-attachments/files/18381699/tika-924666.pdf"
     name = "tika-924666.pdf"
     reader = PdfReader(BytesIO(get_data_from_url(url, name=name)))
     writer = PdfWriter()
@@ -1518,7 +1546,7 @@ def test_update_form_fields(tmp_path):
 
 @pytest.mark.enable_socket
 def test_update_form_fields2():
-    myFiles = {
+    my_files = {
         "test1": {
             "name": "Test1 Form",
             "url": "https://github.com/py-pdf/pypdf/files/14817365/test1.pdf",
@@ -1561,15 +1589,15 @@ def test_update_form_fields2():
     }
     merger = PdfWriter()
 
-    for file in myFiles:
+    for file in my_files:
         reader = PdfReader(
-            BytesIO(get_data_from_url(myFiles[file]["url"], name=myFiles[file]["path"]))
+            BytesIO(get_data_from_url(my_files[file]["url"], name=my_files[file]["path"]))
         )
         reader.add_form_topname(file)
         writer = PdfWriter(clone_from=reader)
 
         writer.update_page_form_field_values(
-            None, myFiles[file]["usage"]["fields"], auto_regenerate=True
+            None, my_files[file]["usage"]["fields"], auto_regenerate=True
         )
         merger.append(writer)
     assert merger.get_form_text_fields(True) == {
@@ -1697,6 +1725,7 @@ def test_watermark_rendering(tmp_path):
     assert image_similarity(png_path, target_png_path) >= 0.95
 
 
+@pytest.mark.samples
 @pytest.mark.skipif(GHOSTSCRIPT_BINARY is None, reason="Requires Ghostscript")
 def test_watermarking_reportlab_rendering(tmp_path):
     """
@@ -1772,7 +1801,7 @@ def test_missing_fields(pdf_file_path):
         writer.update_page_form_field_values(
             writer.pages[0], {"foo": "some filled in text"}, flags=1
         )
-    assert exc.value.args[0] == "No /AcroForm dictionary in PdfWriter Object"
+    assert exc.value.args[0] == "No /AcroForm dictionary in PDF of PdfWriter Object"
 
     writer = PdfWriter()
     writer.append(reader, [0])
@@ -1781,7 +1810,7 @@ def test_missing_fields(pdf_file_path):
         writer.update_page_form_field_values(
             writer.pages[0], {"foo": "some filled in text"}, flags=1
         )
-    assert exc.value.args[0] == "No /Fields dictionary in Pdf in PdfWriter Object"
+    assert exc.value.args[0] == "No /Fields dictionary in PDF of PdfWriter Object"
 
 
 def test_missing_info():
@@ -2481,3 +2510,100 @@ def test_append_pdf_with_dest_without_page(caplog):
     writer.append(reader)
     assert "/__WKANCHOR_8" not in writer.named_destinations
     assert len(writer.named_destinations) == 3
+
+
+@pytest.mark.enable_socket
+def test_destination_is_nullobject():
+    """Tests for #2958"""
+    url = "https://github.com/user-attachments/files/17822279/C0.00.-.COVER.SHEET.pdf"
+    name = "iss2958.pdf"
+    source_data = BytesIO(get_data_from_url(url, name=name))
+    writer = PdfWriter()
+    writer.append(source_data)
+
+
+@pytest.mark.enable_socket
+def test_destination_page_is_none():
+    """Tests for #2963"""
+    url = "https://github.com/user-attachments/files/17879461/3.pdf"
+    name = "iss2963.pdf"
+    reader = PdfReader(BytesIO(get_data_from_url(url, name=name)))
+    writer = PdfWriter()
+    writer.append(reader)
+
+
+def test_stream_not_closed():
+    """Tests for #2905"""
+    src = RESOURCE_ROOT / "pdflatex-outline.pdf"
+    with NamedTemporaryFile(suffix=".pdf") as tmp:
+        with PdfReader(src) as reader, PdfWriter() as writer:
+            writer.add_page(reader.pages[0])
+            writer.write(tmp)
+        assert not tmp.file.closed
+
+    with NamedTemporaryFile(suffix=".pdf") as target:
+        with PdfWriter(target.file) as writer:
+            writer.add_blank_page(100, 100)
+        assert not target.file.closed
+
+    with open(src, "rb") as fileobj:
+        with PdfWriter(fileobj) as writer:
+            pass
+        assert not fileobj.closed
+
+
+def test_auto_write(tmp_path):
+    """Another test for #2905"""
+    target = tmp_path / "out.pdf"
+    with PdfWriter(target) as writer:
+        writer.add_blank_page(100, 100)
+    assert target.stat().st_size > 0
+
+
+def test_deprecate_with_as():
+    """Yet another test for #2905"""
+    with PdfWriter() as writer:
+        with pytest.warns(DeprecationWarning) as w:
+            val = writer.with_as_usage
+        assert "with_as_usage is deprecated" in w[0].message.args[0]
+        assert val
+        with pytest.warns(DeprecationWarning) as w:
+            writer.with_as_usage = val  # old code allowed setting this, so...
+        assert "with_as_usage is deprecated" in w[0].message.args[0]
+
+
+@pytest.mark.skipif(GHOSTSCRIPT_BINARY is None, reason="Requires Ghostscript")
+@pytest.mark.enable_socket
+def test_inline_image_q_operator_handling(tmp_path):
+    """Test for #2927"""
+    pdf_url = "https://github.com/user-attachments/files/17614880/test_clean.pdf"
+    pdf_name = "iss2927.pdf"
+    pdf_data = BytesIO(get_data_from_url(pdf_url, name=pdf_name))
+
+    png_url = "https://github.com/user-attachments/assets/abe16f48-9afa-4179-b1e8-62be27b95c26"
+    png_name = "iss2927.png"
+    expected_png_path = tmp_path / "expected.png"
+    expected_png_path.write_bytes(get_data_from_url(png_url, name=png_name))
+
+    writer = PdfWriter()
+    writer.append(pdf_data)
+    for page in writer.pages:
+        page.transfer_rotation_to_content()
+
+    pdf_path = tmp_path / "out.pdf"
+    png_path = tmp_path / "actual.png"
+
+    writer.write(pdf_path)
+    # False positive: https://github.com/PyCQA/bandit/issues/333
+    subprocess.run(  # noqa: S603
+        [
+            GHOSTSCRIPT_BINARY,
+            "-r120",
+            "-sDEVICE=pngalpha",
+            "-o",
+            png_path,
+            pdf_path,
+        ]
+    )
+    assert png_path.is_file()
+    assert image_similarity(png_path, expected_png_path) >= 0.99999
